#
# spec file for package python-flask-jwt-extended
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flask-jwt-extended
Version:        4.6.0
Release:        2.1
Summary:        A Flask extension that provides JWT support
License:        MIT
URL:            https://github.com/vimalloc/flask-jwt-extended
Source:         https://files.pythonhosted.org/packages/source/F/Flask-JWT-Extended/Flask-JWT-Extended-%{version}.tar.gz
BuildRequires:  %{python_module Flask >= 1.0}
BuildRequires:  %{python_module PyJWT >= 2.0}
BuildRequires:  %{python_module Werkzeug >= 0.14}
BuildRequires:  %{python_module cryptography >= 3.3.1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 1.0
Requires:       python-PyJWT >= 2.0
Requires:       python-Werkzeug >= 0.14
Suggests:       python-cryptography >= 3.3.1
BuildArch:      noarch
%python_subpackages

%description
Flask-JWT-Extended not only adds support for using JSON Web Tokens
(JWT) to Flask for protecting views, but also many
(optional) features built in to make working with JSON
Web Tokens easier. These include:

- Support for adding custom claims to JSON Web Tokens
- Custom claims validation on received tokens
- Creating tokens from complex objects or complex object from received tokens
- Refresh tokens
- Token freshness and separate view decorators to only allow fresh tokens
- Token revoking/blacklisting
- Storing tokens in cookies and CSRF protection

%prep
%setup -q -n Flask-JWT-Extended-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/flask_jwt_extended

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/flask_jwt_extended
%{python_sitelib}/[Ff]lask_[Jj][Ww][Tt]_[Ee]xtended-%{version}.dist-info

%changelog
* Tue Apr 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6.0:
  * Bump cryptography from 41.0.4 to 41.0.6
  * Do not check JWT_TOKEN_LOCATION when testing if
    cookie_csrf_protect is enabled
- update to 4.5.3:
  * Replace "defining" with "define"
  * Fix documentation syntax error
  * remove duplicate comments
  * Support python 3.12 and add support for flask 3.0
* Mon Jun 19 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.5.2:
  * Updated typing of expires_delta and fresh by @eMaerthin in #510
  * Allow selective disabling of blocklist check by @indrajeet307 in #501
  * Fix compatibility with flask version 2.3 (#493)
  * Drop support for python 3.6
  * Add option to include current_user in jinja templates by default (#478)
  * Fix mypy type checks for current_user (#488)
  * Fix mypy explicitly mark exported names #484
  * Fix verify_type being set to False by default in
    verify_jwt_in_request() #483
  * Fix PEP 561 compatibility #480
  * Drop support for Flask 1
  * Add verify_type argument to view decorators to allow accepting both
    refresh & access tokens #460
  * Relax dependency pinning for cryptography package (#467)
* Sat Feb 19 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * be more specific in %%files section
- update to version 4.3.1:
  * Handle new cryptography versioning scheme
  * Fix lint errors
  * Fix typos in documentation
  * Fix reversed docstrings for unset cookie funcs
  * Update automatic_user_loading.py
- changes from version 4.3.0:
  * Feat: override cookie domain from cookie utils
  * Fix typos in view_decorators.py
  * Correct JWT_REFRESH_COOKIE_NAME option description
  * Fix/support flask 2 and flask 1
- changes from version 4.2.3:
  * Ignore coverage for quick fix unitl I can get a better spec in
    place
  * Fix this extension when using Flask 1.x.x
- changes from version 4.2.2:
  * Added async support to jwt_required view decorator
  * Simplify requirements.txt to fix new pip resolver issue
  * Change jwt.required to jwt_required
  * Bump urllib3 from 1.26.4 to 1.26.5
* Fri May 21 2021 John Vandenberg <jayvdb@gmail.com>
- Add python-cryptography as Suggests
- Update to v4.2.1
  * Many breaking changes. Please see
    https://flask-jwt-extended.readthedocs.io/en/stable/v4_upgrade_guide/
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.24.1:
  * Fixes a bug where missing JWTs were not being handled gracefully
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.24.0:
  * Adds the ability to add custom data to the JWT headers via the
    headers kwarg
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.23.0:
  * Make header reading compliant with RFC7230, section 3.2.2
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.22.0:
  * Adds ability to check CSRF double submit token from form data instead of
    headers
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Trim metadata redundancies from summary. Trim filler wording
  from description.
* Mon Aug 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.21.0:
  * Require flask 1.0 or greater (#263)
  * Move docs to pallets-sphinx-themes (#261)
  * Add a new JWT_DECODE_ISSUER option for use with other JWT providers (#259)
  * Gracefully handle errors for malformed tokens (#246)
* Tue Jul 23 2019 Sean Marlow <sean.marlow@suse.com>
- Update Flask minimum version requirement.
* Wed Jul 17 2019 Sean Marlow <sean.marlow@suse.com>
- Update to v3.20.0 (2019-07-17)
  + Initial release.
